@@ -7,7 +7,7 @@ from .common import ReporterFactory
 
 
 class TableCommand(HighWatermarkCommand):
-    """Generate an HTML table with all records in the peak memory usage."""
+    """Generate an HTML table with all records in the peak memory usage"""
 
     def __init__(self) -> None:
         super().__init__(
